*
* This software will feature the 68HC08XL36 Timer Interface Module in an
* input capture example.  A specified channel will erceive pulses or 
* periods and interrupt the CPU on a specified edge.
* Assembled with IASM08 Ver. 3.03
*
* Register Equates
TSC		equ $20	; Timer Status & Control Register $20
TDMA		equ $21	; Timer DMA Select Register $21
TCNTH		equ $22	; Timer Counter Register Hi $22
TCNTL		equ $23	; Timer Counter Register Lo $23
TMODH		equ $24	; Timer Counter Modulo Register Hi $24
TMODL		equ $25	; Timer Counter Modulo Register Lo $25
TSC0		equ $26	; Timer Channel 0 Status & Control Register $26
TCH0H		equ $27	; Timer Channel 0 Register Hi $27
TCH0L		equ $28	; Timer Channel 0 Register Lo $28
TSC1		equ $29	; Timer Channel 1 Status & Control Register $29
TCH1H		equ $2A	; Timer Channel 1 Register Hi $2a
TCH1L		equ $2B	; Timer Channel 1 Register Lo $2b
TSC2		equ $2C	; Timer Channel 2 Status & Control Register $2c
TCH2H		equ $2D	; Timer Channel 2 Register Hi $2d
TCH2L		equ $2E	; Timer Channel 2 Register Lo $2e
TSC3		equ $2F	; Timer Channel 3 Status & Control Register $2f
TCH3H		equ $30	; Timer Channel 3 Register Hi $30
TCH3L		equ $31	; Timer Channel 3 Register Lo $31

* Misc Equates
BIT0		equ $00
BIT1		equ $01
BIT2		equ $02
BIT3		equ $03
BIT4		equ $04
BIT5		equ $05
BIT6		equ $06
BIT7		equ $07
CHOFFSET	equ $00	; ch0=0 offset, ch1=3 offset, chx=3x offset

* TIM status and control register bits
PRESCLR 	equ $00	; prescaler xxxxx000 (bus clock/1)
TOE		equ $00	; timer overflow interrupt enable x0xxxxxx

* Channel x status and control register bits
CHIE		equ $40	; channel interrupt enable x0xxxxxx
MOD		equ $00	; mode select bits xx00xxxx (input capture)
EDG		equ $04	; edge select bits xxxx00xx (rising edge)

* Variables in RAM
		org $0050	; start of RAM

* Application assembly code
		org $6E00	; start of ROM
ICAP_INIT:

* Set up channel x for input capture
	mov #TOE+$30+PRESCLR,TSC	; stop and reset TIM, select 
						; prescaler, TOE
	ldx #TSC0+CHOFFSET		; point to channel x SCR
	lda #CHIE+MOD+EDG
	sta ,x				; store channel ICAP info
	cli					; enable CPU interrupts (delete this 
						; line if polling)
	bclr BIT5,TSC			; enable timer counter
	bra *					; wait for interrupt (to poll 
						; monitor channel x flag)

* channel x interrupt service routine for ICAPx

CHISR	equ *
	pshh			; save h register
	lda TSC0+CHOFFSET	; clear it
* read time value from channel register
	pulh			; retrieve h register
	rti			; return from interrupt routine

* Application vectors
	
	org $FFEE
	fdb CHISR
	fdb CHISR
	fdb CHISR
	fdb CHISR
	org $FFFE
	fdb ICAP_INIT
