*
* This software will feature the 68HC08XL36 Timer Interface Module in an
* output compare example.  A signal with 50% duty cycle and specified
* period will be generated on a specified channel.
* Assembled with IASM08 Ver. 3.03
*
* Register Equates
TSC             equ $20 ; Timer Status & Control Register $20
TDMA            equ $21 ; Timer DMA Select Register $21
TCNTH           equ $22 ; Timer Counter Register Hi $22
TCNTL           equ $23 ; Timer Counter Register Lo $23
TMODH           equ $24 ; Timer Counter Modulo Register Hi $24
TMODL           equ $25 ; Timer Counter Modulo Register Lo $25
TSC0            equ $26 ; Timer Channel 0 Status & Control Register $26
TCH0H           equ $27 ; Timer Channel 0 Register Hi $27
TCH0L           equ $28 ; Timer Channel 0 Register Lo $28
TSC1            equ $29 ; Timer Channel 1 Status & Control Register $29
TCH1H           equ $2A ; Timer Channel 1 Register Hi $2a
TCH1L           equ $2B ; Timer Channel 1 Register Lo $2b
TSC2            equ $2C ; Timer Channel 2 Status & Control Register $2c
TCH2H           equ $2D ; Timer Channel 2 Register Hi $2d
TCH2L           equ $2E ; Timer Channel 2 Register Lo $2e
TSC3            equ $2F ; Timer Channel 3 Status & Control Register $2f
TCH3H           equ $30 ; Timer Channel 3 Register Hi $30
TCH3L           equ $31 ; Timer Channel 3 Register Lo $31

PORTE           equ $08 ; Port E, TIM port

* Misc Equates
BIT0            equ $00
BIT1            equ $01
BIT2            equ $02
BIT3            equ $03
BIT4            equ $04
BIT5            equ $05
BIT6            equ $06
BIT7            equ $07
CHOFFSET        equ $00 ; ch0=0 offset, ch1=3 offset, chx=3x offset
PERHI           equ $80 ; 16.4ms period, 4.1ms offset from bus clock
PERLO           equ $00

* TIM status and control register bits
PRESCLR         equ $00 ; prescaler xxxxx000 (bus clock/1)
TOE             equ $00 ; timer overflow interrupt enable x0xxxxxx

* Channel x status and control register bits
CHIE            equ $00 ; channel interrupt enable x0xxxxxx
MOD             equ $10 ; mode select bits xx00xxxx (output compare)
EDG             equ $04 ; edge select bits xxxx00xx (toggle output)
TOV             equ $00 ; toggle on overflow bit

* Variables in RAM
                org $0050       ; start of RAM

* Application assembly code
                org $6E00       ; start of ROM
OC_INIT:

* Set up channel x for output compare
        mov #TOE+$30+PRESCLR,TSC        ; stop and reset TIM, select
                                                ; prescaler, TOE
        ldx #TSC0+CHOFFSET              ; point to channel x SCR
        lda #CHIE+MOD+EDG+TOV
        sta ,x                          ; store channel ICAP info

        lda #PERHI                              ; set up signal period
        sta 1,x
        lda #PERLO                              ; store low byte
        sta 2,x

        bclr BIT5,TSC                   ; enable timer counter
        bra *

* Interrupt service routines

* Application vectors

        org $FFFE
        fdb OC_INIT
